// 1. 引入依赖
const multer = require("multer");
const path = require("path");
const fs = require("fs");
// 2. 封装处理路径函数
const handlePath = (dir) => {
    return path.join(__dirname, "./", dir);
};

// 3. 设置 multer 的配置对象
const storage = multer.diskStorage({
    // 3.1 存储路径
    destination: function (req, file, cb) {
        let originalname = req.body.imgFileName;
        //let originalname = Buffer.from(file.originalname, "latin1").toString("utf8"); // 将原始文件名进行utf-8编码处理
        if (!(file.mimetype === "image/jpeg" || file.mimetype === "image/png")) {
            cb({
                success: false,
                msg: `仅支持 jpg/png 格式的图片: ${originalname}`,
            });
            return;
        } 
        if (!/^\w+\.\w+$/.test(req.body.imgFileName)) {
            cb({
                success: false,
                msg: `图片名须为字母数字或下划线: ${req.body.imgFileName}`,
            });
            return;
        }
        if (fs.existsSync(`${__dirname}/../../../CustomGetMap/.img/${req.body.imgFileName}`)) {
            cb({
                success: false,
                msg: `图片名已存在, 请更换图片名: ${req.body.imgFileName}`,
            });
            return;
        }
        cb(null, handlePath(`../../../CustomGetMap/.img`));
    },
    //  3.2 存储名称
    filename: function (req, file, cb) {
        let originalname = req.body.imgFileName;
        // let originalname =  Buffer.from(file.originalname, "latin1").toString("utf8"); // 将原始文件名进行utf-8编码处理
        // 将图片名称分割伪数组，用于截取图片的后缀
        //const fileFormat = file.originalname.split('.');
        // 自定义图片名称
        cb(null, originalname);
        //cb(null, Date.now() + '.' + fileFormat[fileFormat.length - 1]);
    },
});


// 4. 为 multer 添加配置
const multerConfig = multer({
    storage: storage,
    limits: { fileSize: Config.ImgSizeMax } // 限制文件大小2M
});

module.exports = multerConfig;
